Learn R Programming

tenm (version 0.5.1)

sp.temporal.bg-class: S3 classes to organize data and results of tenm objects

Description

S3 classes to organize data and results of tenm objects

Arguments

Value

An object of class 'sp.temporal.bg'. The object inherits information from objects of classes 'sp.temporal.modeling' and 'sp.temporal.env'. This class adds environmental background information.

Author

Luis Osorio-Olvera